Crate kcr_radapp_io

Crate kcr_radapp_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the radapp.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

radapp.io/v1alpha3

  • DeploymentResource
  • DeploymentTemplate
  • Recipe

Modules

v1alpha3